@@ -1,7 +1,5 @@
 """Calculate graph edge bearings."""
 
-import warnings
-
 import matplotlib.pyplot as plt
 import networkx as nx
 import numpy as np
@@ -54,32 +52,6 @@ def calculate_bearing(lat1, lng1, lat2, lng2):
     return initial_bearing % 360
 
 
-def get_bearing(origin_point, destination_point):
-    """
-    Do not use, deprecated.
-
-    Parameters
-    ----------
-    origin_point : tuple
-        deprecated, do not use
-    destination_point : tuple
-        deprecated, do not use
-
-    Returns
-    -------
-    bearing : float
-        deprecated, do not use
-    """
-    msg = (
-        "The `get_bearing` function has been deprecated and will be removed in a "
-        "future release. Use the vectorized `bearing.calculate_bearing` instead."
-    )
-    warnings.warn(msg)
-    return calculate_bearing(
-        origin_point[0], origin_point[1], destination_point[0], destination_point[1]
-    )
-
-
 def add_edge_bearings(G, precision=1):
     """
     Add compass `bearing` attributes to all graph edges.
@@ -87,8 +59,8 @@ def add_edge_bearings(G, precision=1):
     Vectorized function to calculate (initial) bearing from origin node to
     destination node for each edge in a directed, unprojected graph then add
     these bearings as new edge attributes. Bearing represents angle in degrees
-    (clockwise) between north and the geodesic line from from the origin node
-    to the destination node. Ignores self-loop edges as their bearings are
+    (clockwise) between north and the geodesic line from the origin node to
+    the destination node. Ignores self-loop edges as their bearings are
     undefined.
 
     Parameters
@@ -183,7 +155,7 @@ def _extract_edge_bearings(Gu, min_length=0, weight=None):
     """
     if nx.is_directed(Gu) or projection.is_projected(Gu.graph["crs"]):  # pragma: no cover
         raise ValueError("graph must be undirected and unprojected to analyze edge bearings")
-    bearings = list()
+    bearings = []
     for u, v, data in Gu.edges(data=True):
         # ignore self-loops and any edges below min_length
         if u != v and data["length"] >= min_length:
