@@ -6,8 +6,8 @@ import multiprocessing as mp
 import networkx as nx
 import numpy as np
 import pandas as pd
-from rtree.index import Index as RTreeIndex
 from shapely.geometry import Point
+from shapely.strtree import STRtree
 
 from . import projection
 from . import utils
@@ -101,15 +101,25 @@ def euclidean_dist_vec(y1, x1, y2, x2):
     return ((x1 - x2) ** 2 + (y1 - y2) ** 2) ** 0.5
 
 
-def add_edge_lengths(G, precision=3):
+def add_edge_lengths(G, precision=3, edges=None):
     """
     Add `length` attribute (in meters) to each edge.
 
     Vectorized function to calculate great-circle distance between each edge's
     incident nodes. Ensure graph is in unprojected coordinates, and
-    unsimplified to get accurate distances. Note: this function is run by all
-    the `graph.graph_from_x` functions automatically to add `length`
-    attributes to all edges.
+    unsimplified to get accurate distances.
+
+    Note: this function is run by all the `graph.graph_from_x` functions
+    automatically to add `length` attributes to all edges. It calculates edge
+    lengths as the great-circle distance from node `u` to node `v`. When
+    OSMnx automatically runs this function upon graph creation, it does it
+    before simplifying the graph: thus it calculates the straight-line lengths
+    of edge segments that are themselves all straight. Only after
+    simplification do edges take on a (potentially) curvilinear geometry. If
+    you wish to calculate edge lengths later, you are calculating
+    straight-line distances which necessarily ignore the curvilinear geometry.
+    You only want to run this function on a graph with all straight edges
+    (such as is the case with an unsimplified graph).
 
     Parameters
     ----------
@@ -117,14 +127,21 @@ def add_edge_lengths(G, precision=3):
         unprojected, unsimplified input graph
     precision : int
         decimal precision to round lengths
+    edges : tuple
+        tuple of (u, v, k) tuples representing subset of edges to add length
+        attributes to. if None, add lengths to all edges.
 
     Returns
     -------
     G : networkx.MultiDiGraph
         graph with edge length attributes
     """
+    if edges is None:
+        uvk = tuple(G.edges)
+    else:
+        uvk = edges
+
     # extract edge IDs and corresponding coordinates from their nodes
-    uvk = tuple(G.edges)
     x = G.nodes(data="x")
     y = G.nodes(data="y")
     try:
@@ -226,18 +243,17 @@ def nearest_edges(G, X, Y, interpolate=None, return_dist=False):
     will return the nearest edge to each point.
 
     If `interpolate` is None, search for the nearest edge to each point, one
-    at a time, using an r-tree and minimizing the euclidean distances from the
+    at a time, using an R-tree and minimizing the euclidean distances from the
     point to the possible matches. For accuracy, use a projected graph and
-    points. This method is precise and also fastest if searching for few
-    points relative to the graph's size.
+    points. This method is precise and fast, particularly when searching for
+    relatively few points compared to the graph's size.
 
-    For a faster method if searching for many points relative to the graph's
-    size, use the `interpolate` argument to interpolate points along the edges
-    and index them. If the graph is projected, this uses a k-d tree for
-    euclidean nearest neighbor search, which requires that scipy is installed
-    as an optional dependency. If graph is unprojected, this uses a ball tree
-    for haversine nearest neighbor search, which requires that scikit-learn is
-    installed as an optional dependency.
+    For an alternative method, use the `interpolate` argument to interpolate
+    points along the edges and index them. If the graph is projected, this
+    uses a k-d tree for euclidean nearest neighbor search, which requires that
+    scipy is installed as an optional dependency. If graph is unprojected,
+    this uses a ball tree for haversine nearest neighbor search, which
+    requires that scikit-learn is installed as an optional dependency.
 
     Parameters
     ----------
@@ -276,23 +292,22 @@ def nearest_edges(G, X, Y, interpolate=None, return_dist=False):
     if interpolate is None:
 
         # build the r-tree spatial index by position for subsequent iloc
-        rtree = RTreeIndex()
-        for pos, bounds in enumerate(geoms.bounds.values):
-            rtree.insert(pos, bounds)
+        rtree = STRtree(geoms)
 
-        # use r-tree to find possible nearest neighbors, one point at a time,
-        # then minimize euclidean distance from point to the possible matches
-        ne_dist = list()
-        for xy in zip(X, Y):
-            dists = geoms.iloc[list(rtree.nearest(xy, num_results=10))].distance(Point(xy))
-            ne_dist.append((dists.idxmin(), dists.min()))
-        ne, dist = zip(*ne_dist)
+        # use r-tree to find each point's nearest neighbor and distance
+        points = [Point(xy) for xy in zip(X, Y)]
+        pos, dist = rtree.query_nearest(points, all_matches=False, return_distance=True)
+
+        # if user passed X/Y lists, the 2nd subarray contains geom indices
+        if len(pos.shape) > 1:
+            pos = pos[1]
+        ne = geoms.iloc[pos].index
 
     # otherwise, if interpolation distance was provided
     else:
 
         # interpolate points along edges to index with k-d tree or ball tree
-        uvk_xy = list()
+        uvk_xy = []
         for uvk, geom in zip(geoms.index, geoms.values):
             uvk_xy.extend((uvk, xy) for xy in utils_geo.interpolate_points(geom, interpolate))
         labels, xy = zip(*uvk_xy)
