@@ -41,7 +41,7 @@ def _get_osm_filter(network_type):
     # define built-in queries to send to the API. specifying way["highway"]
     # means that all ways returned must have a highway tag. the filters then
     # remove ways by tag/value.
-    filters = dict()
+    filters = {}
 
     # driving: filter out un-drivable roads, service roads, private ways, and
     # anything specifying motor=no. also filter out any non-service roads that
@@ -267,7 +267,7 @@ def _get_host_by_name(host):
     ip_address : string
         resolved IP address
     """
-    dns_url = f"https://dns.google/resolve?name={host}"
+    dns_url = f"https://8.8.8.8/resolve?name={host}"
     response = requests.get(dns_url)
     data = response.json()
 
@@ -338,7 +338,7 @@ def _get_pause(base_endpoint, recursive_delay=5, default_duration=60):
     Parameters
     ----------
     base_endpoint : string
-        base Overpass API endpoint (without "/status" at the end)
+        base Overpass API url (without "/status" at the end)
     recursive_delay : int
         how long to wait between recursive calls if the server is currently
         running a query
@@ -359,7 +359,7 @@ def _get_pause(base_endpoint, recursive_delay=5, default_duration=60):
         url = base_endpoint.rstrip("/") + "/status"
         response = requests.get(url, headers=_get_http_headers(), **settings.requests_kwargs)
         sc = response.status_code
-        status = response.text.split("\n")[3]
+        status = response.text.split("\n")[4]
         status_first_token = status.split(" ")[0]
 
     except Exception:  # pragma: no cover
@@ -460,7 +460,7 @@ def _create_overpass_query(polygon_coord_str, tags):
     if not isinstance(tags, dict):  # pragma: no cover
         raise TypeError(error_msg)
 
-    tags_dict = dict()
+    tags_dict = {}
     for key, value in tags.items():
 
         if isinstance(value, bool):
