@@ -2,7 +2,6 @@
 
 import multiprocessing as mp
 import time
-import warnings
 from hashlib import sha1
 from pathlib import Path
 
@@ -12,7 +11,6 @@ import pandas as pd
 import requests
 
 from . import downloader
-from . import settings
 from . import utils
 from . import utils_graph
 
@@ -56,6 +54,8 @@ def add_node_elevations_raster(G, filepath, band=1, cpus=None):
     If `filepath` is a list of paths, this will generate a virtual raster
     composed of the files at those paths as an intermediate step.
 
+    See also the `add_edge_grades` function.
+
     Parameters
     ----------
     G : networkx.MultiDiGraph
@@ -77,6 +77,8 @@ def add_node_elevations_raster(G, filepath, band=1, cpus=None):
 
     if cpus is None:
         cpus = mp.cpu_count()
+    cpus = min(cpus, mp.cpu_count())
+    utils.log(f"Attaching elevations with {cpus} CPUs...")
 
     # if a list of filepaths is passed, compose them all as a virtual raster
     # use the sha1 hash of the filepaths list as the vrt filename
@@ -84,7 +86,7 @@ def add_node_elevations_raster(G, filepath, band=1, cpus=None):
         filepaths = [str(p) for p in filepath]
         sha = sha1(str(filepaths).encode("utf-8")).hexdigest()
         filepath = f"./.osmnx_{sha}.vrt"
-        gdal.BuildVRT(filepath, filepaths)
+        gdal.BuildVRT(filepath, filepaths).FlushCache()
 
     nodes = utils_graph.graph_to_gdfs(G, edges=False, node_geometry=False)[["x", "y"]]
     if cpus == 1:
@@ -107,21 +109,30 @@ def add_node_elevations_raster(G, filepath, band=1, cpus=None):
 
 
 def add_node_elevations_google(
-    G, api_key, max_locations_per_batch=350, pause_duration=0, precision=3
+    G,
+    api_key,
+    max_locations_per_batch=350,
+    pause_duration=0,
+    precision=3,
+    url_template="https://maps.googleapis.com/maps/api/elevation/json?locations={}&key={}",
 ):  # pragma: no cover
     """
     Add `elevation` (meters) attribute to each node using a web service.
 
-    This uses the Google Maps Elevation API and requires an API key. For a
-    free, local alternative, see the `add_node_elevations_raster` function.
-    See also the `add_edge_grades` function.
+    By default, this uses the Google Maps Elevation API but you can optionally
+    use an equivalent API with the same interface and response format, such as
+    Open Topo Data. The Google Maps Elevation API requires an API key but
+    other providers may not.
+
+    For a free local alternative see the `add_node_elevations_raster`
+    function. See also the `add_edge_grades` function.
 
     Parameters
     ----------
     G : networkx.MultiDiGraph
         input graph
     api_key : string
-        a Google Maps Elevation API key
+        a valid API key
     max_locations_per_batch : int
         max number of coordinate pairs to submit in each API call (if this is
         too high, the server will reject the request because its character
@@ -131,19 +142,16 @@ def add_node_elevations_google(
         rate limited
     precision : int
         decimal precision to round elevation values
+    url_template : string
+        a URL string template for the API endpoint, containing exactly two
+        parameters: `locations` and `key`; for example, for Open Topo Data:
+        "https://api.opentopodata.org/v1/aster30m?locations={}&key={}"
 
     Returns
     -------
     G : networkx.MultiDiGraph
         graph with node elevation attributes
     """
-    # different elevation API endpoints formatted ready for use
-    endpoints = {
-        "google": "https://maps.googleapis.com/maps/api/elevation/json?locations={}&key={}",
-        "airmap": "https://api.airmap.com/elevation/v1/ele?points={}",
-    }
-    url_template = endpoints[settings.elevation_provider]
-
     # make a pandas series of all the nodes' coordinates as 'lat,lng'
     # round coordinates to 5 decimal places (approx 1 meter) to be able to fit
     # in more locations per API call
@@ -158,103 +166,47 @@ def add_node_elevations_google(
     results = []
     for i in range(0, len(node_points), max_locations_per_batch):
         chunk = node_points.iloc[i : i + max_locations_per_batch]
-
-        if settings.elevation_provider == "google":
-            locations = "|".join(chunk)
-            url = url_template.format(locations, api_key)
-        elif settings.elevation_provider == "airmap":
-            locations = ",".join(chunk)
-            url = url_template.format(locations)
+        locations = "|".join(chunk)
+        url = url_template.format(locations, api_key)
 
         # check if this request is already in the cache (if global use_cache=True)
         cached_response_json = downloader._retrieve_from_cache(url)
         if cached_response_json is not None:
             response_json = cached_response_json
         else:
-            try:
-                # request the elevations from the API
-                utils.log(f"Requesting node elevations: {url}")
-                time.sleep(pause_duration)
-                if settings.elevation_provider == "google":
-                    response = requests.get(url)
-                elif settings.elevation_provider == "airmap":
-                    headers = {
-                        "X-API-Key": api_key,
-                        "Content-Type": "application/json; charset=utf-8",
-                    }
-                    response = requests.get(url, headers=headers)
+            # request the elevations from the API
+            utils.log(f"Requesting node elevations: {url}")
+            time.sleep(pause_duration)
+            response = requests.get(url)
+            if response.status_code == 200:
                 response_json = response.json()
                 downloader._save_to_cache(url, response_json, response.status_code)
-            except Exception as e:
-                utils.log(e)
-                utils.log(f"Server responded with {response.status_code}: {response.reason}")
+            else:
+                raise Exception(
+                    f"Server responded with {response.status_code}: {response.reason} \n{response.json()}"
+                )
 
         # append these elevation results to the list of all results
-        if settings.elevation_provider == "google":
-            results.extend(response_json["results"])
-        elif settings.elevation_provider == "airmap":
-            results.extend(response_json["data"])
+        results.extend(response_json["results"])
 
     # sanity check that all our vectors have the same number of elements
     if not (len(results) == len(G) == len(node_points)):
         raise Exception(
-            f"Graph has {len(G)} nodes but we received {len(results)} results from elevation API"
+            f"Graph has {len(G)} nodes but we received {len(results)} results. \n{response_json}"
         )
     else:
-        utils.log(
-            f"Graph has {len(G)} nodes and we received {len(results)} results from elevation API"
-        )
+        utils.log(f"Graph has {len(G)} nodes and we received {len(results)} results.")
 
     # add elevation as an attribute to the nodes
     df = pd.DataFrame(node_points, columns=["node_points"])
-    if settings.elevation_provider == "google":
-        df["elevation"] = [result["elevation"] for result in results]
-    elif settings.elevation_provider == "airmap":
-        df["elevation"] = results
+    df["elevation"] = [result["elevation"] for result in results]
     df["elevation"] = df["elevation"].round(precision)
     nx.set_node_attributes(G, name="elevation", values=df["elevation"].to_dict())
-    utils.log("Added elevation data from web service to all nodes.")
+    utils.log("Added elevation data from API to all nodes.")
 
     return G
 
 
-def add_node_elevations(
-    G, api_key, max_locations_per_batch=350, pause_duration=0, precision=3
-):  # pragma: no cover
-    """
-    Do not use, deprecated, will be removed in a future release.
-
-    This function and the `elevation_provider` setting are deprecated.
-
-    Parameters
-    ----------
-    G : networkx.MultiDiGraph
-        deprecated, do not use
-    api_key : string
-        deprecated, do not use
-    max_locations_per_batch : int
-        deprecated, do not use
-    pause_duration : float
-        deprecated, do not use
-    precision : int
-        deprecated, do not use
-
-    Returns
-    -------
-    G : networkx.MultiDiGraph
-    """
-    msg = (
-        "The add_node_elevations function and the 'airmap' elevation_provider are "
-        "deprecated and will be removed in a future release. Use the "
-        "add_node_elevations_google function or the add_node_elevations_raster "
-        "function instead."
-    )
-    warnings.warn(msg)
-    return add_node_elevations_google(
-        G, api_key, max_locations_per_batch, pause_duration, precision
-    )
-
-
 def add_edge_grades(G, add_absolute=True, precision=3):
     """
     Add `grade` attribute to each graph edge.
@@ -263,7 +215,8 @@ def add_edge_grades(G, add_absolute=True, precision=3):
     for each edge in the graph and add it to the edge as an attribute. Nodes
     must already have `elevation` attributes to use this function.
 
-    See also the `add_node_elevations` function.
+    See also the `add_node_elevations_raster` and `add_node_elevations_google`
+    functions.
 
     Parameters
     ----------
