@@ -14,11 +14,12 @@ import warnings
 import geopandas as gpd
 import numpy as np
 import pandas as pd
+from shapely.errors import GEOSException
+from shapely.errors import TopologicalError
 from shapely.geometry import LineString
 from shapely.geometry import MultiPolygon
 from shapely.geometry import Point
 from shapely.geometry import Polygon
-from shapely.geos import TopologicalError
 from shapely.ops import linemerge
 from shapely.ops import polygonize
 
@@ -368,8 +369,8 @@ def _create_gdf(response_jsons, polygon, tags):
         utils.log(f"Converting {elements_count} elements in JSON responses to geometries")
 
         # Dictionaries to hold nodes and complete geometries
-        coords = dict()
-        geometries = dict()
+        coords = {}
+        geometries = {}
 
         # Set to hold the unique IDs of elements that do not have tags
         untagged_element_ids = set()
@@ -501,7 +502,7 @@ def _parse_node_to_point(element):
     point : dict
         dict of OSM ID, OSM element type, tags and geometry
     """
-    point = dict()
+    point = {}
     point["osmid"] = element["id"]
     point["element_type"] = "node"
 
@@ -536,7 +537,7 @@ def _parse_way_to_linestring_or_polygon(element, coords, polygon_features=_polyg
     """
     nodes = element["nodes"]
 
-    linestring_or_polygon = dict()
+    linestring_or_polygon = {}
     linestring_or_polygon["osmid"] = element["id"]
     linestring_or_polygon["element_type"] = "way"
     linestring_or_polygon["nodes"] = nodes
@@ -570,7 +571,7 @@ def _parse_way_to_linestring_or_polygon(element, coords, polygon_features=_polyg
             # if it is a Polygon
             try:
                 geometry = Polygon([(coords[node]["lon"], coords[node]["lat"]) for node in nodes])
-            except ValueError as e:
+            except (GEOSException, ValueError) as e:
                 # XMLs may include geometries that are incomplete, in which
                 # case return an empty geometry
                 utils.log(
@@ -584,7 +585,7 @@ def _parse_way_to_linestring_or_polygon(element, coords, polygon_features=_polyg
                 geometry = LineString(
                     [(coords[node]["lon"], coords[node]["lat"]) for node in nodes]
                 )
-            except ValueError as e:
+            except (GEOSException, ValueError) as e:
                 # XMLs may include geometries that are incomplete, in which
                 # case return an empty geometry
                 utils.log(
@@ -703,7 +704,7 @@ def _parse_relation_to_multipolygon(element, geometries):
     multipolygon : dict
         dict of tags and geometry for a single multipolygon
     """
-    multipolygon = dict()
+    multipolygon = {}
     multipolygon["osmid"] = element["id"]
     multipolygon["element_type"] = "relation"
 
@@ -802,7 +803,7 @@ def _assemble_multipolygon_component_polygons(element, geometries):
     if merged_outer_linestrings.geom_type == "LineString":
         outer_polygons += polygonize(merged_outer_linestrings)
     elif merged_outer_linestrings.geom_type == "MultiLineString":
-        for merged_outer_linestring in list(merged_outer_linestrings):
+        for merged_outer_linestring in list(merged_outer_linestrings.geoms):
             outer_polygons += polygonize(merged_outer_linestring)
 
     # Merge inner linestring fragments.
@@ -869,7 +870,7 @@ def _subtract_inner_polygons_from_outer_polygons(element, outer_polygons, inner_
         if outer_polygon.geom_type == "Polygon":
             outer_polygons_with_holes.append(outer_polygon)
         elif outer_polygon.geom_type == "MultiPolygon":
-            outer_polygons_with_holes.extend(list(outer_polygon))
+            outer_polygons_with_holes.extend(list(outer_polygon.geoms))
 
     # if only one polygon with holes was created, return that single polygon
     if len(outer_polygons_with_holes) == 1:
