@@ -8,6 +8,7 @@ import matplotlib.pyplot as plt
 import networkx as nx
 import numpy as np
 import pandas as pd
+from matplotlib import colormaps
 
 from . import graph
 from . import projection
@@ -42,7 +43,7 @@ def get_colors(n, cmap="viridis", start=0.0, stop=1.0, alpha=1.0, return_hex=Fal
     -------
     color_list : list
     """
-    color_list = [cm.get_cmap(cmap)(x) for x in np.linspace(start, stop, n)]
+    color_list = [colormaps[cmap](x) for x in np.linspace(start, stop, n)]
     if return_hex:
         color_list = [colors.to_hex(c) for c in color_list]
     else:
@@ -319,7 +320,7 @@ def plot_graph_route(
     return fig, ax
 
 
-def plot_graph_routes(G, routes, route_colors="r", **pgr_kwargs):
+def plot_graph_routes(G, routes, route_colors="r", route_linewidths=4, **pgr_kwargs):
     """
     Plot several routes along a graph.
 
@@ -331,6 +332,8 @@ def plot_graph_routes(G, routes, route_colors="r", **pgr_kwargs):
         routes as a list of lists of node IDs
     route_colors : string or list
         if string, 1 color for all routes. if list, the colors for each route.
+    route_linewidths : int or list
+        if int, 1 linewidth for all routes. if list, the linewidth for each route.
     pgr_kwargs
         keyword arguments to pass to plot_graph_route
 
@@ -348,14 +351,19 @@ def plot_graph_routes(G, routes, route_colors="r", **pgr_kwargs):
         route_colors = [route_colors] * len(routes)
     if len(routes) != len(route_colors):  # pragma: no cover
         raise ValueError("route_colors list must have same length as routes")
+    if isinstance(route_linewidths, int):
+        route_linewidths = [route_linewidths] * len(routes)
+    if len(routes) != len(route_linewidths):  # pragma: no cover
+        raise ValueError("route_linewidths list must have same length as routes")
 
     # plot the graph and the first route
-    override = {"route", "route_color", "show", "save", "close"}
+    override = {"route", "route_color", "route_linewidth", "show", "save", "close"}
     kwargs = {k: v for k, v in pgr_kwargs.items() if k not in override}
     fig, ax = plot_graph_route(
         G,
         route=routes[0],
         route_color=route_colors[0],
+        route_linewidth=route_linewidths[0],
         show=False,
         save=False,
         close=False,
@@ -365,11 +373,13 @@ def plot_graph_routes(G, routes, route_colors="r", **pgr_kwargs):
     # plot the subsequent routes on top of existing ax
     override.update({"ax"})
     kwargs = {k: v for k, v in pgr_kwargs.items() if k not in override}
-    for route, route_color in zip(routes[1:], route_colors[1:]):
+    r_rc_rlw = zip(routes[1:], route_colors[1:], route_linewidths[1:])
+    for route, route_color, route_linewidth in r_rc_rlw:
         fig, ax = plot_graph_route(
             G,
             route=route,
             route_color=route_color,
+            route_linewidth=route_linewidth,
             show=False,
             save=False,
             close=False,
@@ -492,7 +502,7 @@ def plot_figure_ground(
 
     if smooth_joints:
         # for each node, get a nodesize according to the narrowest incident edge
-        node_widths = dict()
+        node_widths = {}
         for node in Gu.nodes:
             # first, identify all the highway types of this node's incident edges
             ie_data = [Gu.get_edge_data(node, nbr) for nbr in Gu.neighbors(node)]
@@ -519,7 +529,7 @@ def plot_figure_ground(
                 # anything larger from extending past smallest street's line.
                 # circle marker sizes are in area, so use diameter squared.
                 circle_diameter = max(edge_widths)
-                circle_area = circle_diameter ** 2
+                circle_area = circle_diameter**2
                 node_widths[node] = circle_area
 
         # assign the node size to each node in the graph
@@ -551,6 +561,8 @@ def plot_footprints(
     ax=None,
     figsize=(8, 8),
     color="orange",
+    edge_color="none",
+    edge_linewidth=0,
     alpha=None,
     bgcolor="#111111",
     bbox=None,
@@ -573,6 +585,10 @@ def plot_footprints(
         if ax is None, create new figure with size (width, height)
     color : string
         color of the footprints
+    edge_color : string
+        color of the edge of the footprints
+    edge_linewidth : float
+        width of the edge of the footprints
     alpha : float
         opacity of the footprints
     bgcolor : string
@@ -605,7 +621,9 @@ def plot_footprints(
 
     # retain only Polygons and MultiPolygons, then plot
     gdf = gdf[gdf["geometry"].type.isin({"Polygon", "MultiPolygon"})]
-    ax = gdf.plot(ax=ax, facecolor=color, edgecolor="none", linewidth=0, alpha=alpha)
+    ax = gdf.plot(
+        ax=ax, facecolor=color, edgecolor=edge_color, linewidth=edge_linewidth, alpha=alpha
+    )
 
     # determine figure extents
     if bbox is None:
@@ -660,7 +678,7 @@ def _get_colors_by_value(vals, num_bins, cmap, start, stop, na_color, equal_size
 
         # linearly map a color to each attribute value
         normalizer = colors.Normalize(full_min, full_max)
-        scalar_mapper = cm.ScalarMappable(normalizer, cm.get_cmap(cmap))
+        scalar_mapper = cm.ScalarMappable(normalizer, colormaps[cmap])
         color_series = vals.map(scalar_mapper.to_rgba)
         color_series.loc[pd.isnull(vals)] = na_color
 
