@@ -192,7 +192,32 @@ def _get_paths_to_simplify(G, strict=True):
                 yield _build_path(G, endpoint, successor, endpoints)
 
 
-def simplify_graph(G, strict=True, remove_rings=True):
+def _remove_rings(G):
+    """
+    Remove self-contained rings from graph.
+
+    This identifies any connected components that form a self-contained ring
+    without any endpoints, and removes them from the graph.
+
+    Parameters
+    ----------
+    G : networkx.MultiDiGraph
+        input graph
+
+    Returns
+    -------
+    G : networkx.MultiDiGraph
+        graph with self-contained rings removed
+    """
+    nodes_in_rings = set()
+    for wcc in nx.weakly_connected_components(G):
+        if not any(_is_endpoint(G, n) for n in wcc):
+            nodes_in_rings.update(wcc)
+    G.remove_nodes_from(nodes_in_rings)
+    return G
+
+
+def simplify_graph(G, strict=True, remove_rings=True, track_merged=False):
     """
     Simplify a graph's topology by removing interstitial nodes.
 
@@ -202,7 +227,9 @@ def simplify_graph(G, strict=True, remove_rings=True):
     a new `geometry` attribute on the new edge. Note that only simplified
     edges receive a `geometry` attribute. Some of the resulting consolidated
     edges may comprise multiple OSM ways, and if so, their multiple attribute
-    values are stored as a list.
+    values are stored as a list. Optionally, the simplified edges can receive
+    a `merged_edges` attribute that contains a list of all the (u, v) node
+    pairs that were merged together.
 
     Parameters
     ----------
@@ -215,6 +242,9 @@ def simplify_graph(G, strict=True, remove_rings=True):
         have multiple OSM IDs within them too.
     remove_rings : bool
         if True, remove isolated self-contained rings that have no endpoints
+    track_merged : bool
+        if True, add `merged_edges` attribute on simplified edges, containing
+        a list of all the (u, v) node pairs that were merged together
 
     Returns
     -------
@@ -242,9 +272,14 @@ def simplify_graph(G, strict=True, remove_rings=True):
 
         # add the interstitial edges we're removing to a list so we can retain
         # their spatial geometry
-        path_attributes = dict()
+        merged_edges = []
+        path_attributes = {}
         for u, v in zip(path[:-1], path[1:]):
 
+            if track_merged:
+                # keep track of the edges that were merged
+                merged_edges.append((u, v))
+
             # there should rarely be multiple edges between interstitial nodes
             # usually happens if OSM has duplicate ways digitized for just one
             # street... we will keep only one of the edges (see below)
@@ -283,6 +318,10 @@ def simplify_graph(G, strict=True, remove_rings=True):
             [Point((G.nodes[node]["x"], G.nodes[node]["y"])) for node in path]
         )
 
+        if track_merged:
+            # add the merged edges as a new attribute of the simplified edge
+            path_attributes["merged_edges"] = merged_edges
+
         # add the nodes and edge to their lists for processing at the end
         all_nodes_to_remove.extend(path[1:-1])
         all_edges_to_add.append(
@@ -298,14 +337,7 @@ def simplify_graph(G, strict=True, remove_rings=True):
     G.remove_nodes_from(set(all_nodes_to_remove))
 
     if remove_rings:
-        # remove any connected components that form a self-contained ring
-        # without any endpoints
-        wccs = nx.weakly_connected_components(G)
-        nodes_in_rings = set()
-        for wcc in wccs:
-            if not any(_is_endpoint(G, n) for n in wcc):
-                nodes_in_rings.update(wcc)
-        G.remove_nodes_from(nodes_in_rings)
+        G = _remove_rings(G)
 
     # mark graph as having been simplified
     G.graph["simplified"] = True
@@ -329,6 +361,8 @@ def consolidate_intersections(
     tolerance argument should be adjusted to approximately match street design
     standards in the specific street network, and you should always use a
     projected graph to work in meaningful and consistent units like meters.
+    Note the tolerance represents a per-node buffering radius: for example, to
+    consolidate nodes within 10 meters of each other, use tolerance=5.
 
     When rebuild_graph=False, it uses a purely geometrical (and relatively
     fast) algorithm to identify "geometrically close" nodes, merge them, and
@@ -496,11 +530,12 @@ def _consolidate_intersections_rebuild_graph(G, tolerance=10, reconnect_edges=Tr
                 suffix = 0
                 for wcc in wccs:
                     # set subcluster xy to the centroid of just these nodes
-                    subcluster_centroid = node_points.loc[wcc].unary_union.centroid
-                    gdf.loc[wcc, "x"] = subcluster_centroid.x
-                    gdf.loc[wcc, "y"] = subcluster_centroid.y
+                    idx = list(wcc)
+                    subcluster_centroid = node_points.loc[idx].unary_union.centroid
+                    gdf.loc[idx, "x"] = subcluster_centroid.x
+                    gdf.loc[idx, "y"] = subcluster_centroid.y
                     # move to subcluster by appending suffix to cluster label
-                    gdf.loc[wcc, "cluster"] = f"{cluster_label}-{suffix}"
+                    gdf.loc[idx, "cluster"] = f"{cluster_label}-{suffix}"
                     suffix += 1
 
     # give nodes unique integer IDs (subclusters with suffixes are strings)
